@@ -1,9 +1,10 @@
 from davincirunsdk.notebook.sdk import init_rank_table, start_distributed_train, wait_distributed_train, \
-    start_and_wait_distributed_train
+    start_and_wait_distributed_train, set_random_ms_cache_dir
 
 __all__ = [
     'init_rank_table',
     'start_distributed_train',
     'wait_distributed_train',
-    'start_and_wait_distributed_train'
+    'start_and_wait_distributed_train',
+    'set_random_ms_cache_dir'
 ]
